==> taler-wallet-v0.9.0.tar.gz: taler-wallet-v0.9.0/packages/merchant-backoffice-ui/src/components/notifications/Notifications.stories.tsx <==
/*
 This file is part of GNU Taler
 (C) 2021 Taler Systems S.A.

 GNU Taler is free software; you can redistribute it and/or modify it under the
 terms of the GNU General Public License as published by the Free Software
 Foundation; either version 3, or (at your option) any later version.

 GNU Taler is distributed in the hope that it will be useful, but WITHOUT ANY
 WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
 A PARTICULAR PURPOSE.  See the GNU General Public License for more details.

 You should have received a copy of the GNU General Public License along with
 GNU Taler; see the file COPYING.  If not, see <http://www.gnu.org/licenses/>
 */

/**
*
* @author Sebastian Javier Marchano (sebasjm)
*/

import { h } from 'preact';
import { Notifications } from './index';


export default {
  title: 'Components/Notification',
  component: Notifications,
  argTypes: {
    removeNotification: { action: 'removeNotification' },
  },
};

export const Info = (a: any) => <Notifications {...a} />;
Info.args = {
  notifications: [{
    message: 'Title',
    description: 'Some large description',
    type: 'INFO',
  }]
}
export const Warn = (a: any) => <Notifications {...a} />;
Warn.args = {
  notifications: [{
    message: 'Title',
    description: 'Some large description',
    type: 'WARN',
  }]
}
export const Error = (a: any) => <Notifications {...a} />;
Error.args = {
  notifications: [{
    message: 'Title',
    description: 'Some large description',
    type: 'ERROR',
  }]
}

==> taler-wallet-v0.9.4a.tar.gz: taler-wallet-v0.9.4a/packages/merchant-backoffice-ui/src/components/notifications/Notifications.stories.tsx <==
/*
 This file is part of GNU Taler
 (C) 2021-2023 Taler Systems S.A.

 GNU Taler is free software; you can redistribute it and/or modify it under the
 terms of the GNU General Public License as published by the Free Software
 Foundation; either version 3, or (at your option) any later version.

 GNU Taler is distributed in the hope that it will be useful, but WITHOUT ANY
 WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
 A PARTICULAR PURPOSE.  See the GNU General Public License for more details.

 You should have received a copy of the GNU General Public License along with
 GNU Taler; see the file COPYING.  If not, see <http://www.gnu.org/licenses/>
 */

/**
 *
 * @author Sebastian Javier Marchano (sebasjm)
 */

import { h } from "preact";
import { Notifications } from "./index.js";

export default {
  title: "Components/Notification",
  component: Notifications,
  argTypes: {
    removeNotification: { action: "removeNotification" },
  },
};

export const Info = (a: any) => <Notifications {...a} />;
Info.args = {
  notifications: [
    {
      message: "Title",
      description: "Some large description",
      type: "INFO",
    },
  ],
};
export const Warn = (a: any) => <Notifications {...a} />;
Warn.args = {
  notifications: [
    {
      message: "Title",
      description: "Some large description",
      type: "WARN",
    },
  ],
};
export const Error = (a: any) => <Notifications {...a} />;
Error.args = {
  notifications: [
    {
      message: "Title",
      description: "Some large description",
      type: "ERROR",
    },
  ],
};
